@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2013 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -120,6 +120,7 @@ class Config:
     'mime_types_files',
     'root_parents',
     'svn_roots',
+    'renamed_roots',
     )
   _allowed_overrides = {
     # Mapping of override types to allowed overridable sections.
@@ -218,7 +219,7 @@ class Config:
 
       ### FIXME: This feels like unnecessary depth of knowledge for a
       ### semi-generic configuration object.
-      if opt == 'cvs_roots' or opt == 'svn_roots':
+      if opt == 'cvs_roots' or opt == 'svn_roots' or opt == 'renamed_roots':
         value = _parse_roots(opt, value)
 
       setattr(sc, opt, value)
@@ -379,6 +380,7 @@ class Config:
 
     self.general.cvs_roots = { }
     self.general.svn_roots = { }
+    self.general.renamed_roots = { }
     self.general.root_parents = []
     self.general.default_root = ''
     self.general.mime_types_files = ["mimetypes.conf"]
