@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2015 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -107,7 +107,7 @@ def _compare_paths(path1, path2):
 
 
 def _rev2optrev(rev):
-  assert type(rev) is int
+  assert type(rev) in (int, long)
   rt = core.svn_opt_revision_t()
   rt.kind = core.svn_opt_revision_number
   rt.value.number = rev
